[Libreoffice-commits] core.git: reportdesign/source

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Tue Jan 7 15:28:14 UTC 2020


 reportdesign/source/ui/inc/DesignView.hxx      |    4 ++--
 reportdesign/source/ui/inc/ReportWindow.hxx    |    4 ++--
 reportdesign/source/ui/inc/ScrollHelper.hxx    |    4 ++--
 reportdesign/source/ui/inc/ViewsWindow.hxx     |    4 ++--
 reportdesign/source/ui/report/DesignView.cxx   |    4 ++--
 reportdesign/source/ui/report/ReportWindow.cxx |    4 ++--
 reportdesign/source/ui/report/ScrollHelper.cxx |    4 ++--
 reportdesign/source/ui/report/ViewsWindow.cxx  |    4 ++--
 8 files changed, 16 insertions(+), 16 deletions(-)

New commits:
commit 416eef52da04708c727b8824e96ee1398fcf8e92
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Fri Jan 3 22:06:49 2020 +0100
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Tue Jan 7 16:27:42 2020 +0100

    Fix typo in code
    
    Change-Id: I768c5ae5a4c2c0b2f50a8eb541a5c7397c355345
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/86206
    Tested-by: Jenkins
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/reportdesign/source/ui/report/DesignView.cxx b/reportdesign/source/ui/report/DesignView.cxx
index e20ce6663e15..0f54a3203e6f 100644
--- a/reportdesign/source/ui/report/DesignView.cxx
+++ b/reportdesign/source/ui/report/DesignView.cxx
@@ -563,9 +563,9 @@ void ODesignView::fillCollapsedSections(::std::vector<sal_uInt16>& _rCollapsedPo
     m_aScrollWindow->fillCollapsedSections(_rCollapsedPositions);
 }
 
-void ODesignView::collapseSections(const uno::Sequence< beans::PropertyValue>& _aCollpasedSections)
+void ODesignView::collapseSections(const uno::Sequence< beans::PropertyValue>& _aCollapsedSections)
 {
-    m_aScrollWindow->collapseSections(_aCollpasedSections);
+    m_aScrollWindow->collapseSections(_aCollapsedSections);
 }
 
 OUString ODesignView::getCurrentPage() const
diff --git a/reportdesign/source/ui/report/ReportWindow.cxx b/reportdesign/source/ui/report/ReportWindow.cxx
index 1d634ccea5b2..fb26a4a77b83 100644
--- a/reportdesign/source/ui/report/ReportWindow.cxx
+++ b/reportdesign/source/ui/report/ReportWindow.cxx
@@ -342,10 +342,10 @@ void OReportWindow::fillCollapsedSections(::std::vector<sal_uInt16>& _rCollapsed
     m_aViewsWindow->fillCollapsedSections(_rCollapsedPositions);
 }
 
-void OReportWindow::collapseSections(const uno::Sequence< css::beans::PropertyValue>& _aCollpasedSections)
+void OReportWindow::collapseSections(const uno::Sequence< css::beans::PropertyValue>& _aCollapsedSections)
 {
 
-    m_aViewsWindow->collapseSections(_aCollpasedSections);
+    m_aViewsWindow->collapseSections(_aCollapsedSections);
 }
 
 void OReportWindow::alignMarkedObjects(ControlModification _nControlModification, bool _bAlignAtSection)
diff --git a/reportdesign/source/ui/report/ScrollHelper.cxx b/reportdesign/source/ui/report/ScrollHelper.cxx
index 2b076349346a..6d9f2006effc 100644
--- a/reportdesign/source/ui/report/ScrollHelper.cxx
+++ b/reportdesign/source/ui/report/ScrollHelper.cxx
@@ -319,9 +319,9 @@ void OScrollWindowHelper::fillCollapsedSections(::std::vector<sal_uInt16>& _rCol
     m_aReportWindow->fillCollapsedSections(_rCollapsedPositions);
 }
 
-void OScrollWindowHelper::collapseSections(const uno::Sequence< css::beans::PropertyValue>& _aCollpasedSections)
+void OScrollWindowHelper::collapseSections(const uno::Sequence< css::beans::PropertyValue>& _aCollapsedSections)
 {
-    m_aReportWindow->collapseSections(_aCollpasedSections);
+    m_aReportWindow->collapseSections(_aCollapsedSections);
 }
 
 bool OScrollWindowHelper::EventNotify( NotifyEvent& rNEvt )
diff --git a/reportdesign/source/ui/report/ViewsWindow.cxx b/reportdesign/source/ui/report/ViewsWindow.cxx
index bbff52d5e05f..38c7bd2ed83c 100644
--- a/reportdesign/source/ui/report/ViewsWindow.cxx
+++ b/reportdesign/source/ui/report/ViewsWindow.cxx
@@ -1603,9 +1603,9 @@ void OViewsWindow::fillCollapsedSections(::std::vector<sal_uInt16>& _rCollapsedP
     }
 }
 
-void OViewsWindow::collapseSections(const uno::Sequence< beans::PropertyValue>& _aCollpasedSections)
+void OViewsWindow::collapseSections(const uno::Sequence< beans::PropertyValue>& _aCollapsedSections)
 {
-    for (const beans::PropertyValue& rSection : _aCollpasedSections)
+    for (const beans::PropertyValue& rSection : _aCollapsedSections)
     {
         sal_uInt16 nPos = sal_uInt16(-1);
         if ( (rSection.Value >>= nPos) && nPos < m_aSections.size() )


More information about the Libreoffice-commits mailing list
diff --git a/reportdesign/source/ui/inc/DesignView.hxx b/reportdesign/source/ui/inc/DesignView.hxx
index 7b78d7327cf4..7b904b22db11 100644
--- a/reportdesign/source/ui/inc/DesignView.hxx
+++ b/reportdesign/source/ui/inc/DesignView.hxx
@@ -214,9 +214,9 @@ namespace rptui
 
         /** collapse all sections given by their position
         *
         * \param _aCollpasedSections The position of the sections which should be collapsed.
         */
-        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollpasedSections);
+        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollapsedSections);
 
         OUString  getCurrentPage() const;
         void             setCurrentPage(const OUString& _sLastActivePage);
@@ -214,9 +214,9 @@ namespace rptui
         /** collapse all sections given by their position
         *
-        * \param _aCollpasedSections The position of the sections which should be collapsed.
+        * \param _aCollapsedSections The position of the sections which should be collapsed.
         */
diff --git a/reportdesign/source/ui/inc/ReportWindow.hxx b/reportdesign/source/ui/inc/ReportWindow.hxx
index 99fc3aae3a47..1c42e10575d2 100644
--- a/reportdesign/source/ui/inc/ReportWindow.hxx
+++ b/reportdesign/source/ui/inc/ReportWindow.hxx
@@ -191,9 +191,9 @@ namespace rptui
 
         /** collapse all sections given by their position
         *
         * \param _aCollpasedSections The position of the sections which should be collapsed.
         */
-        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollpasedSections);
+        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollapsedSections);
 
         /** align all marked objects in all sections
         */
@@ -191,9 +191,9 @@ namespace rptui
         /** collapse all sections given by their position
         *
-        * \param _aCollpasedSections The position of the sections which should be collapsed.
+        * \param _aCollapsedSections The position of the sections which should be collapsed.
         */
diff --git a/reportdesign/source/ui/inc/ScrollHelper.hxx b/reportdesign/source/ui/inc/ScrollHelper.hxx
index 22a3d428c967..119a1764bd4c 100644
--- a/reportdesign/source/ui/inc/ScrollHelper.hxx
+++ b/reportdesign/source/ui/inc/ScrollHelper.hxx
@@ -183,9 +183,9 @@ namespace rptui
 
         /** collapse all sections given by their position
         *
         * \param _aCollpasedSections The position of the sections which should be collapsed.
         */
-        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollpasedSections);
+        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollapsedSections);
 
         /** align all marked objects in all sections
         */
@@ -183,9 +183,9 @@ namespace rptui
         /** collapse all sections given by their position
         *
-        * \param _aCollpasedSections The position of the sections which should be collapsed.
+        * \param _aCollapsedSections The position of the sections which should be collapsed.
         */
diff --git a/reportdesign/source/ui/inc/ViewsWindow.hxx b/reportdesign/source/ui/inc/ViewsWindow.hxx
index e019e79e8332..d668df78ab4f 100644
--- a/reportdesign/source/ui/inc/ViewsWindow.hxx
+++ b/reportdesign/source/ui/inc/ViewsWindow.hxx
@@ -276,9 +276,9 @@ namespace rptui
 
         /** collapse all sections given by their position
         *
         * \param _aCollpasedSections The position of the sections which should be collapsed.
         */
-        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollpasedSections);
+        void collapseSections(const css::uno::Sequence< css::beans::PropertyValue>& _aCollapsedSections);
 
         /** zoom the ruler and view windows
         */
@@ -276,9 +276,9 @@ namespace rptui
         /** collapse all sections given by their position
         *
-        * \param _aCollpasedSections The position of the sections which should be collapsed.
+        * \param _aCollapsedSections The position of the sections which should be collapsed.
         */